@@ -1,11 +1,9 @@
 import ast
 import json
 import logging
-import os.path
 import sys
 
 from flask import abort, request, url_for
-from jinja2.utils import pass_context
 from packaging.version import parse
 from pypuppetdb.errors import EmptyResponseError
 from requests.exceptions import ConnectionError, HTTPError
@@ -13,14 +11,6 @@ from requests.exceptions import ConnectionError, HTTPError
 log = logging.getLogger(__name__)
 
 
-@pass_context
-def url_static_offline(context, value):
-    request_parts = os.path.split(os.path.dirname(context.name))
-    static_path = '/'.join(request_parts[1:])
-
-    return url_for('static', filename="%s/%s" % (static_path, value))
-
-
 def url_for_field(field, value):
     args = request.view_args.copy()
     args.update(request.args.copy())
@@ -37,13 +27,14 @@ def check_db_version(puppetdb):
     Gets the version of puppetdb and exits if it is not an accepted one.
     """
     try:
-        version = puppetdb.current_version()
-        log.info(f"PuppetDB version: {version}")
+        current_version = puppetdb.current_version()
+        log.info(f"PuppetDB version: {current_version}")
 
-        minimum_version = '5.2.0'
+        current_semver = current_version.split('-')[0]
+        minimum_semver = '5.2.0'
 
-        if parse(version) < parse(minimum_version):
-            log.error(f"The minimum supported version of PuppetDB is {minimum_version}")
+        if parse(current_semver) < parse(minimum_semver):
+            log.error(f"The minimum supported version of PuppetDB is {minimum_semver}")
             sys.exit(1)
 
     except HTTPError as e:
@@ -151,6 +142,6 @@ def quote_columns_data(data: str) -> str:
     return data.replace('.', '\\.')
 
 
-def check_env(env, envs):
+def check_env(env: str, envs: dict):
     if env != '*' and env not in envs:
         abort(404)
